Grvlms - The Openedx distribution
==================================

.. image:: https://ci.groovetechnology.com/buildStatus/icon?job=GrooveGitHub%2Fgrvlms-cli%2Fmaster
    :alt: Build status
    :target: https://ci.groovetechnology.com/job/GrooveGitHub/job/grvlms-cli/job/master/

Please access this https://groovetech.atlassian.net/wiki/spaces/ROE/overview for more information